**nosqlmodel**

nosqlmodel is a NoSql ORM without relations. Easy way to create models with a nosql backend. Currently Redis and Dynamodb supported.



For Detailed description:

`https://gitlab.com/mozgurbayhan/nosqlmodel/blob/master/README.md <https://gitlab.com/mozgurbayhan/nosqlmodel/blob/master/README.md>`_
